@@ -5,13 +5,7 @@
 from syst3m.v1.classes.config import *
 import platform 
 
-# functions.
-def get_argument(id, empty=None):
-	match = False
-	for i in sys.argv:
-		if id == i: match = True
-		elif match == True: return i
-	return empty
+# defaults object class.
 class Defaults(object):
 	def __init__(self):
 
@@ -44,7 +38,7 @@ class Defaults(object):
 	):
 		if sudo or "--sudo" in sys.argv: sudo = "sudo "
 		else: sudo = ""
-		present = "--create-alias" in sys.argv and get_argument("--create-alias") == alias
+		present = "--create-alias" in sys.argv and cl1.get_argument("--create-alias") == alias
 		base = f"/usr/local/bin"
 		if not os.path.exists(base):
 			base = f"/usr/bin/"
@@ -68,6 +62,8 @@ class Defaults(object):
 			quit()
 	def get_source_path(self, path, back=1):
 		return Formats.FilePath(path).base(back=back)
+	def get_log_level(self):
+		return cl1.get_argument("--log-level", empty=0)
 
 # initialized classes.
 defaults = Defaults()
\ No newline at end of file
